Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1951)

Unified Diff: content/browser/frame_host/navigation_request.h

Issue 2797443005: PlzNavigate data pipe
Patch Set: cleanup Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | content/browser/frame_host/navigation_request.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/frame_host/navigation_request.h
diff --git a/content/browser/frame_host/navigation_request.h b/content/browser/frame_host/navigation_request.h
index 2d9b1c04d3ce19f3688a6693205dfbc33d614248..2a142f151045e4f2be5eea479518c67452c82e67 100644
--- a/content/browser/frame_host/navigation_request.h
+++ b/content/browser/frame_host/navigation_request.h
@@ -18,6 +18,7 @@
#include "content/common/navigation_params.h"
#include "content/public/browser/navigation_throttle.h"
#include "content/public/common/previews_state.h"
+#include "mojo/public/cpp/system/data_pipe.h"
namespace content {
@@ -29,7 +30,6 @@ class NavigationURLLoader;
class NavigationData;
class ResourceRequestBody;
class SiteInstanceImpl;
-class StreamHandle;
// PlzNavigate
// A UI thread object that owns a navigation request until it commits. It
@@ -182,7 +182,7 @@ class CONTENT_EXPORT NavigationRequest : public NavigationURLLoaderDelegate {
const net::RedirectInfo& redirect_info,
const scoped_refptr<ResourceResponse>& response) override;
void OnResponseStarted(const scoped_refptr<ResourceResponse>& response,
- std::unique_ptr<StreamHandle> body,
+ mojo::ScopedDataPipeConsumerHandle handle,
const SSLStatus& ssl_status,
std::unique_ptr<NavigationData> navigation_data,
const GlobalRequestID& request_id,
@@ -249,10 +249,11 @@ class CONTENT_EXPORT NavigationRequest : public NavigationURLLoaderDelegate {
std::unique_ptr<NavigationHandleImpl> navigation_handle_;
// Holds the ResourceResponse and the StreamHandle for the navigation while
// the WillProcessResponse checks are performed by the NavigationHandle.
scoped_refptr<ResourceResponse> response_;
- std::unique_ptr<StreamHandle> body_;
+ mojo::ScopedDataPipeConsumerHandle handle_;
base::Closure on_start_checks_complete_closure_;
« no previous file with comments | « no previous file | content/browser/frame_host/navigation_request.cc » ('j') | no next file with comments »
@@ -249,10 +249,11 @@ class CONTENT_EXPORT NavigationRequest : public NavigationURLLoaderDelegate {
std::unique_ptr<NavigationHandleImpl> navigation_handle_;
- // Holds the ResourceResponse and the StreamHandle for the navigation while
- // the WillProcessResponse checks are performed by the NavigationHandle.
+ // Holds the ResourceResponse and the DataPipeConsumerHandle for the
+ // navigation while the WillProcessResponse checks are performed
+ // by the NavigationHandle.
scoped_refptr<ResourceResponse> response_;

Powered by Google App Engine
This is Rietveld 408576698